// restrict.cpp:
//
// restrict non-owner access to a particular file
//
// jim frost 05.03.95

#include <stdio.h>
#include <string.h>
#include "security.hpp"

void
RestrictFile(const char* filename)
{
  SecurityDescriptor* sd = GetFileSecurityDescriptor(filename);

  if (sd == NULL) {
    fprintf(stderr, "%s: %s\n", filename, strerror(GetLastError()));
    return;
  }

  SecurityIdentifier* owner_sid = new SecurityIdentifier(sd->GetOwner());
  SecurityIdentifier* everyone_sid = CreateSecurityIdentifier("Everyone");

  AccessControlList* acl = new AccessControlList;
  //acl->AddDenyAce(0, everyone_sid, FILE_ALL_ACCESS);

  acl->AddAllowAce(0, owner_sid, FILE_ALL_ACCESS);
  sd->SetDiscretionaryAcl(acl);

  // try to change the discretionary ACL
  if (!SetFileSecurityDescriptor(filename, DACL_SECURITY_INFORMATION, sd))
    fprintf(stderr, "%s: %s\n", filename, strerror(GetLastError()));

  delete owner_sid;
  delete everyone_sid;
}

void restrict(LPCSTR fileName)
{
	RestrictFile(fileName);
}
